@@ -1,4 +1,3 @@
-
 import os
 
 from peewee import MySQLDatabase
@@ -55,3 +54,32 @@ def crypte(passwd):
 
         passwd_enc += chr(n_car)
     return passwd_enc
+
+
+def decripte(passwd):
+    passwd_dec = ''
+    if not passwd:
+        return passwd_dec
+    passwd = passwd.lower().lstrip()
+
+    n_car = 0
+    n_last_car = 0
+
+    if len(passwd) == 0:
+        return passwd_dec
+
+    for i in range(1, len(passwd) + 1):
+        n_car = ord(passwd[i - 1:][0])
+
+        if i == 1:
+            n_last_car = n_car
+            n_car = n_car - 5
+        else:
+            if i % 2 != 0:
+                n_car = n_car - (n_last_car % 7)
+            else:
+                n_car = n_car + (n_last_car % 7)
+
+        passwd_dec += chr(n_car)
+
+    return passwd_dec
