@@ -1,11 +1,16 @@
 from peewee import DoesNotExist, OperationalError
+
+from .models.log import LogDefaut, DefDefaut
 from .utils import logger
 from .models import (
     PrescriptionItem, MagasinService, LogAstus, TopFive,
     HistoriqueMultidoses, MessageAstus, FListeError,
     Patient, Sejour, Service, WebviewTaquin, WebviewDemiTaquin,
     WebviewEmplacement, WebviewPatientHisto, LogInfo, LotRetire,
-    GtinAlias
+    GtinAlias, GtinDimension, User, CatalogType, CatalogVersion, CatalogOption,
+    CatalogLines, CatalogUnitStock, CatalogColumns, EquipmentUnitStock, EquipmentColumns,
+    EquipmentLines, LogEchangeRiedl, ListeValide, ItemValide, Historique,
+    UnitDose, MagasinFormat
 )
 from .constant import PatientGlobal
 
@@ -38,6 +43,8 @@ class DbMigrator:
         self.check_model('f_liste_error', FListeError)
         self.check_model('f_log_info', LogInfo)
         self.check_model('f_cip_alias', GtinAlias)
+        self.check_model('f_log_echange_riedl', LogEchangeRiedl)
+        self.check_model('f_mag_format', MagasinFormat)
         self.check_field('f_user', 'x_astup', "ALTER TABLE f_user ADD COLUMN x_astup tinyint(1) DEFAULT '0';")
         self.check_field('f_user', 'x_inventaire', "ALTER TABLE f_user ADD COLUMN x_inventaire tinyint(1) DEFAULT '0';")
         self.check_field('f_user', 'x_login', "ALTER TABLE f_user ADD COLUMN x_login VARCHAR(30) DEFAULT '';")
@@ -57,9 +64,10 @@ class DbMigrator:
                          "ALTER TABLE f_user ADD COLUMN x_is_enabled TINYINT(1) NULL DEFAULT 1;")
         self.check_field('f_user', 'x_is_temporary',
                          "ALTER TABLE f_user ADD COLUMN x_is_temporary TINYINT(1) NULL DEFAULT 1;")
-
-        self.check_field('f_profil', 'x_visu', "ALTER TABLE f_profil ADD COLUMN x_visu TINYINT(1) NULL DEFAULT 0;")
+        self.check_field('f_profil', 'x_visu', "ALTER TABLE f_profil ADD COLUMN x_visu TINYINT(1) NULL DEFAULT 1;")
         self.check_field('f_profil', 'x_edit', "ALTER TABLE f_profil ADD COLUMN x_edit TINYINT(1) NULL DEFAULT 0;")
+        self.check_field('f_profil', 'x_cree', "ALTER TABLE f_profil ADD COLUMN x_cree TINYINT(1) NULL DEFAULT 0;")
+        self.check_field('f_profil', 'x_supp', "ALTER TABLE f_profil ADD COLUMN x_supp TINYINT(1) NULL DEFAULT 0;")
         self.check_field('f_ref', 'x_com_med', "ALTER TABLE f_ref ADD COLUMN x_com_med VARCHAR(100) DEFAULT '';")
         self.check_field('f_ref', 'x_bac', "ALTER TABLE f_ref ADD COLUMN x_bac INT(11) NULL DEFAULT 0;")
         self.check_field('f_ref', 'x_stup', "ALTER TABLE f_ref ADD x_stup TINYINT(1) NOT NULL DEFAULT 0;")
@@ -104,6 +112,24 @@ class DbMigrator:
                          "ALTER TABLE f_adr ADD COLUMN x_service TINYINT(1) NULL DEFAULT 0;")
         self.check_field('f_adr', 'x_bloque_msg',
                          "ALTER TABLE f_adr ADD COLUMN x_bloque_msg varchar(100) NULL DEFAULT '';")
+        # Complete f_format table to implement volume for RIEDL, ASTUS, AIDE-Cut
+        # These fields is for theorical dimensions
+        self.check_field('f_format', 'x_dim_x',
+                         "ALTER TABLE f_format ADD COLUMN x_dim_x INT(11) NULL DEFAULT 0;")
+        self.check_field('f_format', 'x_dim_y',
+                         "ALTER TABLE f_format ADD COLUMN x_dim_y INT(11) NULL DEFAULT 0 AFTER x_dim_x;")
+        self.check_field('f_format', 'x_dim_z',
+                         "ALTER TABLE f_format ADD COLUMN x_dim_z INT(11) NULL DEFAULT 0 AFTER x_dim_y;")
+        # These fields is for real dimensions
+        self.check_field('f_format', 'x_mm_x',
+                         "ALTER TABLE f_format ADD COLUMN x_mm_x INT(11) NULL DEFAULT 0;")
+        self.check_field('f_format', 'x_mm_y',
+                         "ALTER TABLE f_format ADD COLUMN x_mm_y INT(11) NULL DEFAULT 0 AFTER x_mm_x;")
+        self.check_field('f_format', 'x_mm_z',
+                         "ALTER TABLE f_format ADD COLUMN x_mm_z INT(11) NULL DEFAULT 0 AFTER x_mm_y;")
+        # use by ASTUS and RIEDL
+        self.check_field('f_format', 'x_type_bac',
+                         "ALTER TABLE f_format ADD COLUMN x_type_bac varchar(10) NULL DEFAULT '';")
 
         # Table f_dest for Carnet and Riedl Exit
         self.check_field('f_dest', 'x_type_carnet',
@@ -115,6 +141,12 @@ class DbMigrator:
         self.check_field('f_dest', 'x_adr4', "ALTER TABLE f_dest ADD COLUMN x_adr4 VARCHAR(40) NULL DEFAULT ''")
         self.check_field('f_dest', 'x_tk_mode',
                          "ALTER TABLE f_dest ADD COLUMN x_tk_mode VARCHAR(2) NOT NULL DEFAULT 'NO'")
+        self.check_field('f_dest', 'x_rdl_unload_prt_auto',
+                         "ALTER TABLE f_dest ADD COLUMN x_rdl_unload_prt_auto TINYINT(1) NOT NULL DEFAULT 0;")
+        self.check_field('f_peigne', 'x_libelle',
+                         "ALTER TABLE f_peigne ADD COLUMN x_libelle VARCHAR(50) NULL DEFAULT '';")
+        self.check_field('f_peigne', 'x_mode_type',
+                         "ALTER TABLE f_peigne ADD COLUMN x_mode_type VARCHAR(1) NULL DEFAULT '';")
         self.check_field('f_mag', 'x_split_liste',
                          "ALTER TABLE f_mag ADD COLUMN x_split_liste TINYINT(1) NULL DEFAULT 0;")
         self.check_field('f_mag', 'x_libelle',
@@ -129,6 +161,8 @@ class DbMigrator:
         self.check_field('f_item', 'x_liste_orig',
                          "ALTER TABLE f_item ADD COLUMN x_liste_orig VARCHAR(60) NULL DEFAULT ''")
         self.check_field('f_item', 'x_posologie', "ALTER TABLE f_item ADD COLUMN x_posologie TEXT NULL DEFAULT ''")
+        self.check_field('f_item', 'x_cip',
+                         "ALTER TABLE f_item ADD COLUMN x_cip VARCHAR(20) NULL DEFAULT ''")
         self.check_field('f_liste', 'x_sequence',
                          "ALTER TABLE f_liste ADD COLUMN x_sequence VARCHAR(25) NULL DEFAULT ''")
         self.check_field('f_liste', 'x_interface',
@@ -137,14 +171,57 @@ class DbMigrator:
                          "ALTER TABLE f_liste ADD COLUMN x_liste_orig VARCHAR(60) NULL DEFAULT ''")
         self.check_field('f_liste', 'x_num_face',
                          "ALTER TABLE f_liste ADD COLUMN x_num_face INT(11) NULL DEFAULT 0;")
+        self.check_field('f_liste', 'x_createur',
+                         "ALTER TABLE f_liste ADD COLUMN x_createur VARCHAR(20) NULL DEFAULT ''")
+        self.check_field('f_item_w', 'x_cip',
+                         "ALTER TABLE f_item_w ADD COLUMN x_cip VARCHAR(20) NULL DEFAULT ''")
+        self.check_field('f_item_w', 'x_capa',
+                         "ALTER TABLE f_item_w ADD COLUMN x_capa INT(11) NULL DEFAULT 0;")
         self.check_field('f_liste_error', 'x_message',
                          "ALTER TABLE f_liste_error ADD COLUMN x_message TEXT NULL DEFAULT ''")
+        self.check_field('f_ucd_cip', 'x_DU_boite_pass',
+                         "ALTER TABLE f_ucd_cip ADD COLUMN `x_DU_boite_pass` TINYINT(1) NOT NULL DEFAULT 0;")
+        self.check_field('f_histo_blocage', 'x_dfnum',
+                         "ALTER TABLE f_histo_blocage ADD COLUMN x_dfnum SMALLINT(6) NULL DEFAULT 0;")
         # If pk not exists, we drop the table to recreate it
         self.check_field('f_liste_error', 'x_pk',
                          "DROP TABLE IF EXISTS f_liste_error;")
+        self.check_field('f_defaut', 'x_manuel',
+                         "ALTER TABLE f_defaut ADD COLUMN `x_manuel` TINYINT(1) NOT NULL DEFAULT 0;")
         self.check_model('f_liste_error', FListeError)
-
+        self.check_model('f_gtin_dimension', GtinDimension)
+        self.check_model('f_def_defaut', DefDefaut)
+        self.check_model('f_log_defaut', LogDefaut)
+        self.check_model('f_user', User)
+        self.check_field('f_user', 'x_avatar',
+                         "ALTER TABLE f_user ADD COLUMN `x_avatar` VARCHAR(50) NULL ")
+        self.check_field('f_resrc', 'x_group',
+                         "ALTER TABLE f_resrc ADD COLUMN `x_group` VARCHAR(75) NULL ")
+        self.check_model('f_catalog_type', CatalogType)
+        self.check_model('f_catalog_version', CatalogVersion)
+        self.check_model('f_catalog_option', CatalogOption)
+        self.check_field('f_mag', 'x_avatar',
+                         "ALTER TABLE f_mag ADD COLUMN `x_avatar` VARCHAR(50) NULL ")
+        self.check_model('f_catalog_unitstock', CatalogUnitStock)
+        self.check_model('f_catalog_lines', CatalogLines)
+        self.check_model('f_catalog_columns', CatalogColumns)
+        self.check_field('f_catalog_version', 'sub_version',
+                         "ALTER TABLE f_catalog_version ADD COLUMN sub_version VARCHAR(20) NULL DEFAULT ''")
+        self.check_model('f_equipment_unitstock', EquipmentUnitStock)
+        self.check_model('f_equipment_lines', EquipmentLines)
+        self.check_model('f_equipment_columns', EquipmentColumns)
+        self.check_model('f_liste_valide', ListeValide)
+        self.check_model_index(ListeValide)
+        self.check_model('f_item_valide', ItemValide)
         self.check_model_index(LotRetire)
+        self.check_field('f_histo', 'xx_id_plateau',
+                         "ALTER TABLE f_histo ADD COLUMN `xx_id_plateau` VARCHAR(40) NULL DEFAULT '' ")
+        self.check_field('f_histo', 'xx_no_pilulier',
+                         "ALTER TABLE f_histo ADD COLUMN `xx_no_pilulier`INT(11) NULL DEFAULT 0 ")
+        self.check_field('f_histo', 'xx_id_peigne',
+                         "ALTER TABLE f_histo ADD COLUMN `xx_id_peigne` INT(11) NULL DEFAULT 0 ")
+        self.check_model_index(Historique)
+        self.check_model('f_sachet', UnitDose)
 
         self.add_service('DEENOVA', 'Service de test')
         self.add_global_ipp_episode()
@@ -171,16 +248,15 @@ class DbMigrator:
         unique_template = """ALTER TABLE %s ADD CONSTRAINT %s UNIQUE KEY (%s);"""
         index_template = """CREATE INDEX %s USING BTREE ON %s (%s);"""
         table_name = model_class._meta.table_name
-        # print(table_name)
         for idx in model_class._meta.fields_to_index():
             exp = idx._expressions
             fld_list = [x.column.name for x in exp]
 
             if idx._unique:
-                ddl = unique_template % (table_name, idx._name, ", ".join(fld_list))
+                ddl = unique_template % (table_name, "_".join(fld_list), ", ".join(fld_list))
             else:
-                ddl = index_template % (idx._name, table_name, ", ".join(fld_list))
-
+                ddl = index_template % ("_".join(fld_list), table_name, ", ".join(fld_list))
+                print(ddl)
             try:
                 self.db.execute_sql(ddl)
             except OperationalError:
